@@ -1,26 +1,37 @@
+use geo_types::Geometry;
 use std::io::Cursor;
 
+use geozero::wkb::{FromWkb, WkbDialect};
 use numpy::{IntoPyArray, Ix1, PyArray, PyReadonlyArray1};
 use pyo3::exceptions::PyValueError;
 use pyo3::{prelude::*, wrap_pyfunction};
 use rayon::prelude::*;
 
-use h3ron::{compact, Index, ToH3Cells};
+use h3ron::{compact, H3Cell, Index, ToH3Cells};
 
 use crate::error::IntoPyResult;
 
-fn wkbbytes_to_h3(wkbdata: &&[u8], h3_resolution: u8, do_compact: bool) -> PyResult<Vec<u64>> {
+fn wkbbytes_to_h3(wkbdata: &[u8], h3_resolution: u8, do_compact: bool) -> PyResult<Vec<u64>> {
+    // geozero parses empty geometries as Point(0.0, 0.0), so for now we sort out empty geometries
+    // based on the number of bytes
+    if wkbdata.len() <= 9 {
+        return Ok(vec![]);
+    }
     let mut cursor = Cursor::new(wkbdata);
-    match wkb::wkb_to_geom(&mut cursor) {
+    match Geometry::from_wkb(&mut cursor, WkbDialect::Wkb) {
         Ok(g) => {
-            let mut cells = g.to_h3_cells(h3_resolution).into_pyresult()?;
+            let mut cells: Vec<H3Cell> = g
+                .to_h3_cells(h3_resolution)
+                .into_pyresult()?
+                .iter()
+                .collect();
 
             // deduplicate, in the case of overlaps or lines
             cells.sort_unstable();
             cells.dedup();
 
             if do_compact {
-                cells = compact(&cells);
+                cells = compact(&cells).iter().collect();
             }
             Ok(cells.drain(..).map(|i| i.h3index()).collect())
         }
@@ -51,7 +62,7 @@ fn wkbbytes_with_ids_to_h3(
         .zip(wkb_list.iter())
         .par_bridge()
         .map(|(id, wkbdata)| {
-            wkbbytes_to_h3(wkbdata, h3_resolution, do_compact).map(|h3indexes| (*id, h3indexes))
+            wkbbytes_to_h3(*wkbdata, h3_resolution, do_compact).map(|h3indexes| (*id, h3indexes))
         })
         .try_fold(
             || (vec![], vec![]),
