@@ -1,11 +1,19 @@
-import rasterio
+try:
+    import rasterio
+    HAS_RASTERIO = True
+except ImportError:
+    # rasterio provides no pre-compiled windows wheels, so it is an
+    # optional dependency to simplify the CI setup of the github actions workflows
+    HAS_RASTERIO = False
+
 import numpy as np
+import pytest
 
 from h3ronpy.raster import raster_to_dataframe
 
 from . import TESTDATA_PATH
 
-
+@pytest.mark.skipif(not HAS_RASTERIO, reason="requires rasterio")
 def test_r_tiff():
     dataset = rasterio.open(TESTDATA_PATH / "r.tiff")
     band = dataset.read(1)
@@ -15,6 +23,7 @@ def test_r_tiff():
     assert df.dtypes["value"] == "uint8"
 
 
+@pytest.mark.skipif(not HAS_RASTERIO, reason="requires rasterio")
 def test_r_tiff_float32():
     dataset = rasterio.open(TESTDATA_PATH / "r.tiff")
     band = dataset.read(1).astype(np.float32)
